# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protodescriptor.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protodescriptor.proto',
  package='protos',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x15protodescriptor.proto\x12\x06protos\"\x1f\n\x0fProtoDescriptor\x12\x0c\n\x04\x64\x65sc\x18\x01 \x01(\x0c\"\x19\n\tProtoName\x12\x0c\n\x04name\x18\x01 \x01(\t\" \n\x10ProtoDescriptors\x12\x0c\n\x04\x64\x65sc\x18\x01 \x03(\x0c\"\x1a\n\nProtoNames\x12\x0c\n\x04name\x18\x01 \x03(\tb\x06proto3')
)




_PROTODESCRIPTOR = _descriptor.Descriptor(
  name='ProtoDescriptor',
  full_name='protos.ProtoDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='desc', full_name='protos.ProtoDescriptor.desc', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=64,
)


_PROTONAME = _descriptor.Descriptor(
  name='ProtoName',
  full_name='protos.ProtoName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='protos.ProtoName.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=91,
)


_PROTODESCRIPTORS = _descriptor.Descriptor(
  name='ProtoDescriptors',
  full_name='protos.ProtoDescriptors',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='desc', full_name='protos.ProtoDescriptors.desc', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=93,
  serialized_end=125,
)


_PROTONAMES = _descriptor.Descriptor(
  name='ProtoNames',
  full_name='protos.ProtoNames',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='protos.ProtoNames.name', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=153,
)

DESCRIPTOR.message_types_by_name['ProtoDescriptor'] = _PROTODESCRIPTOR
DESCRIPTOR.message_types_by_name['ProtoName'] = _PROTONAME
DESCRIPTOR.message_types_by_name['ProtoDescriptors'] = _PROTODESCRIPTORS
DESCRIPTOR.message_types_by_name['ProtoNames'] = _PROTONAMES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProtoDescriptor = _reflection.GeneratedProtocolMessageType('ProtoDescriptor', (_message.Message,), dict(
  DESCRIPTOR = _PROTODESCRIPTOR,
  __module__ = 'protodescriptor_pb2'
  # @@protoc_insertion_point(class_scope:protos.ProtoDescriptor)
  ))
_sym_db.RegisterMessage(ProtoDescriptor)

ProtoName = _reflection.GeneratedProtocolMessageType('ProtoName', (_message.Message,), dict(
  DESCRIPTOR = _PROTONAME,
  __module__ = 'protodescriptor_pb2'
  # @@protoc_insertion_point(class_scope:protos.ProtoName)
  ))
_sym_db.RegisterMessage(ProtoName)

ProtoDescriptors = _reflection.GeneratedProtocolMessageType('ProtoDescriptors', (_message.Message,), dict(
  DESCRIPTOR = _PROTODESCRIPTORS,
  __module__ = 'protodescriptor_pb2'
  # @@protoc_insertion_point(class_scope:protos.ProtoDescriptors)
  ))
_sym_db.RegisterMessage(ProtoDescriptors)

ProtoNames = _reflection.GeneratedProtocolMessageType('ProtoNames', (_message.Message,), dict(
  DESCRIPTOR = _PROTONAMES,
  __module__ = 'protodescriptor_pb2'
  # @@protoc_insertion_point(class_scope:protos.ProtoNames)
  ))
_sym_db.RegisterMessage(ProtoNames)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pitaya.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import request_pb2 as request__pb2
from . import response_pb2 as response__pb2
from . import push_pb2 as push__pb2
from . import bind_pb2 as bind__pb2
from . import kick_pb2 as kick__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='pitaya.proto',
  package='protos',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0cpitaya.proto\x12\x06protos\x1a\rrequest.proto\x1a\x0eresponse.proto\x1a\npush.proto\x1a\nbind.proto\x1a\nkick.proto2\xd2\x01\n\x06Pitaya\x12+\n\x04\x43\x61ll\x12\x0f.protos.Request\x1a\x10.protos.Response\"\x00\x12.\n\nPushToUser\x12\x0c.protos.Push\x1a\x10.protos.Response\"\x00\x12\x38\n\x11SessionBindRemote\x12\x0f.protos.BindMsg\x1a\x10.protos.Response\"\x00\x12\x31\n\x08KickUser\x12\x0f.protos.KickMsg\x1a\x12.protos.KickAnswer\"\x00\x62\x06proto3')
  ,
  dependencies=[request__pb2.DESCRIPTOR,response__pb2.DESCRIPTOR,push__pb2.DESCRIPTOR,bind__pb2.DESCRIPTOR,kick__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_PITAYA = _descriptor.ServiceDescriptor(
  name='Pitaya',
  full_name='protos.Pitaya',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=92,
  serialized_end=302,
  methods=[
  _descriptor.MethodDescriptor(
    name='Call',
    full_name='protos.Pitaya.Call',
    index=0,
    containing_service=None,
    input_type=request__pb2._REQUEST,
    output_type=response__pb2._RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PushToUser',
    full_name='protos.Pitaya.PushToUser',
    index=1,
    containing_service=None,
    input_type=push__pb2._PUSH,
    output_type=response__pb2._RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SessionBindRemote',
    full_name='protos.Pitaya.SessionBindRemote',
    index=2,
    containing_service=None,
    input_type=bind__pb2._BINDMSG,
    output_type=response__pb2._RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='KickUser',
    full_name='protos.Pitaya.KickUser',
    index=3,
    containing_service=None,
    input_type=kick__pb2._KICKMSG,
    output_type=kick__pb2._KICKANSWER,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_PITAYA)

DESCRIPTOR.services_by_name['Pitaya'] = _PITAYA

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bind.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='bind.proto',
  package='protos',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\nbind.proto\x12\x06protos\"#\n\x07\x42indMsg\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x0b\n\x03\x66id\x18\x02 \x01(\tb\x06proto3')
)




_BINDMSG = _descriptor.Descriptor(
  name='BindMsg',
  full_name='protos.BindMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='protos.BindMsg.uid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fid', full_name='protos.BindMsg.fid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22,
  serialized_end=57,
)

DESCRIPTOR.message_types_by_name['BindMsg'] = _BINDMSG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BindMsg = _reflection.GeneratedProtocolMessageType('BindMsg', (_message.Message,), dict(
  DESCRIPTOR = _BINDMSG,
  __module__ = 'bind_pb2'
  # @@protoc_insertion_point(class_scope:protos.BindMsg)
  ))
_sym_db.RegisterMessage(BindMsg)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cluster.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cluster.proto',
  package='protos',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\rcluster.proto\x12\x06protos\"\x15\n\x06RPCMsg\x12\x0b\n\x03Msg\x18\x01 \x01(\t\"#\n\x06RPCRes\x12\x0b\n\x03Msg\x18\x01 \x01(\t\x12\x0c\n\x04\x43ode\x18\x02 \x01(\x05\x62\x06proto3')
)




_RPCMSG = _descriptor.Descriptor(
  name='RPCMsg',
  full_name='protos.RPCMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Msg', full_name='protos.RPCMsg.Msg', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25,
  serialized_end=46,
)


_RPCRES = _descriptor.Descriptor(
  name='RPCRes',
  full_name='protos.RPCRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Msg', full_name='protos.RPCRes.Msg', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Code', full_name='protos.RPCRes.Code', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=83,
)

DESCRIPTOR.message_types_by_name['RPCMsg'] = _RPCMSG
DESCRIPTOR.message_types_by_name['RPCRes'] = _RPCRES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RPCMsg = _reflection.GeneratedProtocolMessageType('RPCMsg', (_message.Message,), dict(
  DESCRIPTOR = _RPCMSG,
  __module__ = 'cluster_pb2'
  # @@protoc_insertion_point(class_scope:protos.RPCMsg)
  ))
_sym_db.RegisterMessage(RPCMsg)

RPCRes = _reflection.GeneratedProtocolMessageType('RPCRes', (_message.Message,), dict(
  DESCRIPTOR = _RPCRES,
  __module__ = 'cluster_pb2'
  # @@protoc_insertion_point(class_scope:protos.RPCRes)
  ))
_sym_db.RegisterMessage(RPCRes)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: docmsg.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='docmsg.proto',
  package='protos',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0c\x64ocmsg.proto\x12\x06protos\"\x1b\n\x06\x44ocMsg\x12\x11\n\tgetProtos\x18\x01 \x01(\x08\x62\x06proto3')
)




_DOCMSG = _descriptor.Descriptor(
  name='DocMsg',
  full_name='protos.DocMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='getProtos', full_name='protos.DocMsg.getProtos', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24,
  serialized_end=51,
)

DESCRIPTOR.message_types_by_name['DocMsg'] = _DOCMSG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DocMsg = _reflection.GeneratedProtocolMessageType('DocMsg', (_message.Message,), dict(
  DESCRIPTOR = _DOCMSG,
  __module__ = 'docmsg_pb2'
  # @@protoc_insertion_point(class_scope:protos.DocMsg)
  ))
_sym_db.RegisterMessage(DocMsg)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: msg.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='msg.proto',
  package='protos',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\tmsg.proto\x12\x06protos\"\\\n\x03Msg\x12\n\n\x02id\x18\x01 \x01(\x04\x12\r\n\x05route\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\r\n\x05reply\x18\x04 \x01(\t\x12\x1d\n\x04type\x18\x05 \x01(\x0e\x32\x0f.protos.MsgType*F\n\x07MsgType\x12\x0e\n\nMsgRequest\x10\x00\x12\r\n\tMsgNotify\x10\x01\x12\x0f\n\x0bMsgResponse\x10\x02\x12\x0b\n\x07MsgPush\x10\x03\x62\x06proto3')
)

_MSGTYPE = _descriptor.EnumDescriptor(
  name='MsgType',
  full_name='protos.MsgType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MsgRequest', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MsgNotify', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MsgResponse', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MsgPush', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=115,
  serialized_end=185,
)
_sym_db.RegisterEnumDescriptor(_MSGTYPE)

MsgType = enum_type_wrapper.EnumTypeWrapper(_MSGTYPE)
MsgRequest = 0
MsgNotify = 1
MsgResponse = 2
MsgPush = 3



_MSG = _descriptor.Descriptor(
  name='Msg',
  full_name='protos.Msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protos.Msg.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='route', full_name='protos.Msg.route', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='protos.Msg.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reply', full_name='protos.Msg.reply', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='protos.Msg.type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21,
  serialized_end=113,
)

_MSG.fields_by_name['type'].enum_type = _MSGTYPE
DESCRIPTOR.message_types_by_name['Msg'] = _MSG
DESCRIPTOR.enum_types_by_name['MsgType'] = _MSGTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Msg = _reflection.GeneratedProtocolMessageType('Msg', (_message.Message,), dict(
  DESCRIPTOR = _MSG,
  __module__ = 'msg_pb2'
  # @@protoc_insertion_point(class_scope:protos.Msg)
  ))
_sym_db.RegisterMessage(Msg)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: request.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import session_pb2 as session__pb2
from . import msg_pb2 as msg__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='request.proto',
  package='protos',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\rrequest.proto\x12\x06protos\x1a\rsession.proto\x1a\tmsg.proto\"\x8a\x01\n\x07Request\x12\x1d\n\x04type\x18\x01 \x01(\x0e\x32\x0f.protos.RPCType\x12 \n\x07session\x18\x02 \x01(\x0b\x32\x0f.protos.Session\x12\x18\n\x03msg\x18\x03 \x01(\x0b\x32\x0b.protos.Msg\x12\x12\n\nfrontendID\x18\x04 \x01(\t\x12\x10\n\x08metadata\x18\x05 \x01(\x0c*\x1c\n\x07RPCType\x12\x07\n\x03Sys\x10\x00\x12\x08\n\x04User\x10\x01\x62\x06proto3')
  ,
  dependencies=[session__pb2.DESCRIPTOR,msg__pb2.DESCRIPTOR,])

_RPCTYPE = _descriptor.EnumDescriptor(
  name='RPCType',
  full_name='protos.RPCType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Sys', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='User', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=192,
  serialized_end=220,
)
_sym_db.RegisterEnumDescriptor(_RPCTYPE)

RPCType = enum_type_wrapper.EnumTypeWrapper(_RPCTYPE)
Sys = 0
User = 1



_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='protos.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='protos.Request.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session', full_name='protos.Request.session', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg', full_name='protos.Request.msg', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frontendID', full_name='protos.Request.frontendID', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='protos.Request.metadata', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=190,
)

_REQUEST.fields_by_name['type'].enum_type = _RPCTYPE
_REQUEST.fields_by_name['session'].message_type = session__pb2._SESSION
_REQUEST.fields_by_name['msg'].message_type = msg__pb2._MSG
DESCRIPTOR.message_types_by_name['Request'] = _REQUEST
DESCRIPTOR.enum_types_by_name['RPCType'] = _RPCTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), dict(
  DESCRIPTOR = _REQUEST,
  __module__ = 'request_pb2'
  # @@protoc_insertion_point(class_scope:protos.Request)
  ))
_sym_db.RegisterMessage(Request)


# @@protoc_insertion_point(module_scope)



__all__ = ['bind_pb2', 'doc_pb2', 'docmsg_pb2', 'error_pb2',
           'kick_pb2', 'msg_pb2', 'pitaya_pb2', 'protodescriptor_pb2',
           'push_pb2', 'request_pb2', 'response_pb2', 'session_pb2']



""" this module contains pitaya's remotes related logic """

import inspect
from google.protobuf import message


class RemoteMethod(object):
    def __init__(self, obj, method, return_type, arg_type):
        self.obj = obj
        self.method = method
        self.return_type = return_type
        self.arg_type = arg_type


class BaseRemote(object):
    """ remotes that you want to register must inherit from BaseRemote """

    def name(self):
        """ returns the name of the class """
        return self.__class__

    def is_valid_remote(self):
        """ if the class has 1 or more valid remote methods, it's valid """
        m = self.get_remotes_map()
        return len(m) > 0

    def get_remotes_map(self):
        """ this method returns the valid remotes present in the class """
        res = dict()
        members = inspect.getmembers(self, predicate=inspect.ismethod)
        for m in members:
            full_spec = inspect.getfullargspec(m[1])
            annotations = full_spec.annotations
            if annotations:
                # if the return is a subclass of a protobuf message
                if "return" in annotations:
                    if issubclass(annotations['return'], message.Message):
                        if len(full_spec.args) == 2:
                            # if the class has exactly 2 args, being the second a
                            # subclass of protobuf message
                            if full_spec.args[1] in annotations:
                                if issubclass(annotations[full_spec.args[1]],
                                              message.Message):
                                    res[m[1].__name__] = RemoteMethod(
                                        self, m[1].__func__,
                                        annotations['return'],
                                        annotations[full_spec.args[1]])
        return res



from .route import Route
from google.protobuf import message
from ctypes import POINTER, byref, c_char, c_char_p, c_void_p, addressof, memmove, sizeof
from .gen.response_pb2 import Response
from .gen.request_pb2 import Request
from .remote import BaseRemote
from .c_interop import SdConfig, NatsConfig, Server, Native, FREECB, MemoryBuffer, RPCReq, RPCCB, PitayaError, LogLevel

from multiprocessing import cpu_count
from threading import Thread

remotes_dict = dict()
rpc_worker_threads = []

def default_name_func(s): return s[:1].lower() + s[1:] if s else ''

LIB = None

def initialize_pitaya(
        sd_config: SdConfig,
        nats_config: NatsConfig,
        server: Server, log_level: LogLevel, logPath=b'/tmp/pitaya_cluster_log'):
    """ this method initializes pitaya cluster logic and should be called on start """
    global LIB
    LIB = Native().LIB
    res = LIB.tfg_pitc_InitializeWithNats(
        nats_config, sd_config, server, log_level, logPath)
    if not res:
        raise Exception("error initializing pitaya")
    # initialize RPC threads
    for i in range(cpu_count()):
        t = Thread(target=process_rpcs, args=(i,))
        rpc_worker_threads.append(t)
        t.start()


def process_rpcs(thread_num):
    print (f"started working thread {thread_num}")
    while True:
        cRpcPtr = LIB.tfg_pitc_WaitForRpc()
        if bool(cRpcPtr) == False:
            break
        req = cRpcPtr.contents
        try:
            req_data_ptr = req.buffer.contents.data
            req_data_sz = req.buffer.contents.size
            req_data = (c_char * req_data_sz).from_address(req_data_ptr)
            request = Request()
            request.MergeFromString(req_data.value)
            route = Route.from_str(request.msg.route).str()
            if route not in remotes_dict:
                raise Exception("remote %s not found!" % route)
            remote_method = remotes_dict[route]
            arg = remote_method.arg_type()
            arg.MergeFromString(request.msg.data)
            res = remote_method.method(remote_method.obj, arg)
            buf = _alloc_mem_buffer_ptr_with_response_data(res)
            LIB.tfg_pitc_FinishRpcCall(buf, cRpcPtr)
            LIB.tfg_pitc_FreeMem(buf)
        except Exception as e:
            err_str = "exception: %s: %s" % (type(e).__name__, e)
            err = _get_error_response_c_void_p("PIT-500", err_str)
            LIB.tfg_pitc_FinishRpcCall(err, cRpcPtr)
            LIB.tfg_pitc_FreeMem(err)
            continue


def get_server_by_id(server_id: str):
    """ gets a server by its id """
    # TODO needs free -- leak here!
    sv = Server()
    success = LIB.tfg_pitc_GetServerById(server_id.encode('utf-8'), sv)
    if success is False:
        raise Exception('failed to get server {}'.format(server_id))
    # LIB.tfg_pitc_FreeServer(byref(sv))
    return sv


def register_remote(remote: BaseRemote, name="", nameFunc=None):
    """ register a remote, the remote should be a class that inherits from BaseRemote """
    if name == "":
        name = remote.__class__.__name__.lower()
    if not issubclass(type(remote), BaseRemote):
        raise TypeError
    if not remote.is_valid_remote():
        raise Exception("the class %s contains no valid remote methods" %
                        remote.__class__.__name__)
    m_map = remote.get_remotes_map()
    for m in m_map.keys():
        rn = m
        if nameFunc is None:
            nameFunc = default_name_func
        rn = nameFunc(rn)
        name = "%s.%s" % (name, rn)
        if name in remotes_dict:
            raise Exception("tried to register same remote twice! %s" % name)
        # TODO better logger
        print("registered remote: %s" % name)
        remotes_dict[name] = m_map[m]


def shutdown():
    """ shutdown pitaya cluster, should be called on exit """
    LIB.tfg_pitc_Terminate()


def _alloc_mem_buffer_ptr_with_response_data(res: Response):
    """ internal method, this allocs a memory buffer in the global heap for sending it to c code """
    res_bytes = res.SerializeToString()
    ret_len = len(res_bytes)
    ptrData = LIB.tfg_pitc_AllocMem(ret_len)
    ret_data = (c_char * ret_len)(*res_bytes)
    memmove(ptrData, ret_data, ret_len)
    ret = MemoryBuffer()
    ret.data = ptrData
    ret.size = ret_len
    # we alloc mem in c side because doing so from python causes it to be freed the moment we return
    ptrStruct = LIB.tfg_pitc_AllocMem(sizeof(ret))
    memmove(ptrStruct, addressof(ret), sizeof(ret))
    return ptrStruct


def _get_error_response_c_void_p(code, msg):
    """ gets an allocated buffer of an error response """
    res = Response()
    res.error.code = code
    res.error.msg = msg
    return _alloc_mem_buffer_ptr_with_response_data(res)


def send_rpc(route: str, in_msg: message.Message, res_class: message.Message, server_id: str='') -> message.Message:
    """ sends a rpc to other pitaya server """
    if not issubclass(type(in_msg), message.Message) or not issubclass(res_class, message.Message):
        raise TypeError
    msg_bytes = in_msg.SerializeToString()
    msg_len = len(msg_bytes)
    c_bytes = (c_char * msg_len)(*msg_bytes)
    ret_ptr = POINTER(MemoryBuffer)()
    err = PitayaError()
    res = LIB.tfg_pitc_RPC(server_id.encode(
        'utf-8'), route.encode('utf-8'), addressof(c_bytes), msg_len, byref(ret_ptr), byref(err))
    if not res:
        exception_msg = "code: {} msg: {}".format(err.code, err.msg)
        LIB.tfg_pitc_FreePitayaError(err)
        raise Exception(exception_msg)
    ret_bytes = (
        c_char * ret_ptr.contents.size).from_address(ret_ptr.contents.data)
    response = Response()
    response.MergeFromString(ret_bytes.value)
    LIB.tfg_pitc_FreeMemoryBuffer(ret_ptr)
    return response

# MUST be called after get_server or else your code will leak
# TODO: can we prevent the user from not calling this?
# def free_server(server:Server):
#    LIB.tfg_pitc_FreeServer(server)
#



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doc.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='doc.proto',
  package='protos',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\tdoc.proto\x12\x06protos\"\x12\n\x03\x44oc\x12\x0b\n\x03\x64oc\x18\x01 \x01(\tb\x06proto3')
)




_DOC = _descriptor.Descriptor(
  name='Doc',
  full_name='protos.Doc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='doc', full_name='protos.Doc.doc', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21,
  serialized_end=39,
)

DESCRIPTOR.message_types_by_name['Doc'] = _DOC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Doc = _reflection.GeneratedProtocolMessageType('Doc', (_message.Message,), dict(
  DESCRIPTOR = _DOC,
  __module__ = 'doc_pb2'
  # @@protoc_insertion_point(class_scope:protos.Doc)
  ))
_sym_db.RegisterMessage(Doc)


# @@protoc_insertion_point(module_scope)



""" this module interops with the c dll"""
from ctypes import (c_char_p, c_int, c_longlong, c_void_p, cdll, Structure, POINTER,
                    c_bool, CFUNCTYPE)
from typing import NewType
from enum import Enum
import platform
import os
import sys

FREECB = CFUNCTYPE(None, c_void_p)


class SdConfig(Structure):  # pylint: disable=too-few-public-methods
    """ service discovery configuration class """
    _fields_ = [
        ("endpoints", c_char_p),
        ("etcd_prefix", c_char_p),
        ("server_type_filters", c_char_p),
        ("heartbeat_ttl_sec", c_int),
        ("log_heartbeat", c_int),
        ("log_server_sync", c_int),
        ("log_server_details", c_int),
        ("sync_servers_interval_sec", c_int),
        ("max_number_of_retries", c_int)]


class NatsConfig(Structure):  # pylint: disable=too-few-public-methods
    """ nats configuration class """
    _fields_ = [
        ("endpoint", c_char_p),
        ("connection_timeout_ms", c_longlong),
        ("request_timeout_ms", c_int),
        ("max_reconnection_attempts", c_int),
        ("max_pending_msgs", c_int)]


class Server(Structure):  # pylint: disable=too-few-public-methods
    """ server class """
    _fields_ = [
        ("id", c_char_p),
        ("type", c_char_p),
        ("metadata", c_char_p),
        ("hostname", c_char_p),
        ("frontend", c_int)]


class PitayaError(Structure):  # pylint: disable=too-few-public-methods
    """ pitaya error class """
    _fields_ = [
        ("code", c_char_p),
        ("msg", c_char_p)]


class MemoryBuffer(Structure):  # pylint: disable=too-few-public-methods
    """ memory buffer class, this is used to send pointer to data to and from c """
    _fields_ = [
        ("data", c_void_p),
        ("size", c_int)]


class RPCReq(Structure):  # pylint: disable=too-few-public-methods
    """ rpc req class used in sendrpc and rpc cbs """
    _fields_ = [
        ("buffer", POINTER(MemoryBuffer)),
        ("tag", c_void_p)]


RPCCB = CFUNCTYPE(c_void_p, POINTER(RPCReq))

LevelType = NewType('Level', int)
class LogLevel(Enum):
    DEBUG = 0
    INFO = 1
    WARN = 2
    ERROR = 3
    CRITICAL = 4

class Native(object):
    __instance = None

    class __impl:
        def __init__(self):
            lib_dir = os.environ.get('PITAYA_LIB_DIR')
            if lib_dir == None:
                system = platform.system()

                if system == "Linux":
                    lib_dir = "libpitaya_cpp.so"
                elif system == "Darwin":
                    lib_dir = "libpitaya_cpp.dylib"
                elif system == "Windows":
                    lib_dir = "libpitaya_cpp.dll"

                print (
                    "PITAYA_LIB_DIR env var not set, defaulting lib to %s, make sure it's in the current dir" % lib_dir)

            """ Implementation of the singleton interface """

            self.LIB = cdll.LoadLibrary(lib_dir)

            self.LIB.tfg_pitc_InitializeWithNats.restype = c_bool
            self.LIB.tfg_pitc_InitializeWithNats.argtypes = [POINTER(NatsConfig), POINTER(SdConfig), POINTER(Server),
                                                    c_int, c_char_p]

            self.LIB.tfg_pitc_GetServerById.restype = c_bool
            self.LIB.tfg_pitc_GetServerById.argtypes = [
                c_char_p, POINTER(Server)]

            self.LIB.tfg_pitc_FreeServer.argtypes = [POINTER(Server)]

            self.LIB.tfg_pitc_Terminate.restype = None

            self.LIB.tfg_pitc_FreeMemoryBuffer.argtypes = [
                POINTER(MemoryBuffer)]

            self.LIB.tfg_pitc_FreePitayaError.argtypes = [POINTER(PitayaError)]

            self.LIB.tfg_pitc_RPC.restype = c_bool
            self.LIB.tfg_pitc_RPC.argtypes = [c_char_p, c_char_p, c_void_p, c_int,
                                              POINTER(POINTER(MemoryBuffer)), POINTER(PitayaError)]

            self.LIB.tfg_pitc_FreeMem.argtypes = [c_void_p]

            self.LIB.tfg_pitc_AllocMem.restype = c_void_p
            self.LIB.tfg_pitc_AllocMem.argtypes = [c_int]

            self.LIB.tfg_pitc_WaitForRpc.restype = POINTER(RPCReq)

            self.LIB.tfg_pitc_FinishRpcCall.argtypes = [c_void_p,POINTER(RPCReq)]

    def __init__(self):
        if Native.__instance is None:
            Native.__instance = Native.__impl()
        self.__dict__['_Native__instance'] = Native.__instance

    def __getattr__(self, attr):
        """ Delegate access to implementation """
        return getattr(self.__instance, attr)

    def __setattr__(self, attr, value):
        """ Delegate access to implementation """
        return setattr(self.__instance, attr, value)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='pitayaserver',
    version='0.3.0',
    author="TFG Co",
    author_email="backend@tfgco.com",
    description="A library for creating pitaya backend servers using python",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/topfreegames/libpitaya-cluster",
    packages=setuptools.find_packages(),
    install_requires=[
        'protobuf',
        'uuid',
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: push.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='push.proto',
  package='protos',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\npush.proto\x12\x06protos\"0\n\x04Push\x12\r\n\x05route\x18\x01 \x01(\t\x12\x0b\n\x03uid\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x62\x06proto3')
)




_PUSH = _descriptor.Descriptor(
  name='Push',
  full_name='protos.Push',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='route', full_name='protos.Push.route', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid', full_name='protos.Push.uid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='protos.Push.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22,
  serialized_end=70,
)

DESCRIPTOR.message_types_by_name['Push'] = _PUSH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Push = _reflection.GeneratedProtocolMessageType('Push', (_message.Message,), dict(
  DESCRIPTOR = _PUSH,
  __module__ = 'push_pb2'
  # @@protoc_insertion_point(class_scope:protos.Push)
  ))
_sym_db.RegisterMessage(Push)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: response.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import error_pb2 as error__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='response.proto',
  package='protos',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0eresponse.proto\x12\x06protos\x1a\x0b\x65rror.proto\"6\n\x08Response\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x1c\n\x05\x65rror\x18\x02 \x01(\x0b\x32\r.protos.Errorb\x06proto3')
  ,
  dependencies=[error__pb2.DESCRIPTOR,])




_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='protos.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='protos.Response.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='protos.Response.error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39,
  serialized_end=93,
)

_RESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSE,
  __module__ = 'response_pb2'
  # @@protoc_insertion_point(class_scope:protos.Response)
  ))
_sym_db.RegisterMessage(Response)


# @@protoc_insertion_point(module_scope)



""" this module constains pitaya route related logic """


class Route(object):
    """ class for dealing with pitaya routes"""

    def __init__(self, server_type, service, method):
        self.server_type = server_type
        self.service = service
        self.method = method

    def __repr__(self):
        return "%s.%s" % (self.service, self.method)

    def str(self):
        """ returns str representation of route """
        return self.__repr__()

    @classmethod
    def from_str(cls, route_str):
        """ creates a new route from a string """
        route_splitted = route_str.split(".")
        if len(route_splitted) < 3:
            raise Exception("invalid route %s" % route_str)
        instance = cls(route_splitted[0], route_splitted[1], route_splitted[2])
        return instance



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='error.proto',
  package='protos',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0b\x65rror.proto\x12\x06protos\"\x82\x01\n\x05\x45rror\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12-\n\x08metadata\x18\x03 \x03(\x0b\x32\x1b.protos.Error.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')
)




_ERROR_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='protos.Error.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='protos.Error.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='protos.Error.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=107,
  serialized_end=154,
)

_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='protos.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='protos.Error.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg', full_name='protos.Error.msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='protos.Error.metadata', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ERROR_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24,
  serialized_end=154,
)

_ERROR_METADATAENTRY.containing_type = _ERROR
_ERROR.fields_by_name['metadata'].message_type = _ERROR_METADATAENTRY
DESCRIPTOR.message_types_by_name['Error'] = _ERROR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), dict(

  MetadataEntry = _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), dict(
    DESCRIPTOR = _ERROR_METADATAENTRY,
    __module__ = 'error_pb2'
    # @@protoc_insertion_point(class_scope:protos.Error.MetadataEntry)
    ))
  ,
  DESCRIPTOR = _ERROR,
  __module__ = 'error_pb2'
  # @@protoc_insertion_point(class_scope:protos.Error)
  ))
_sym_db.RegisterMessage(Error)
_sym_db.RegisterMessage(Error.MetadataEntry)


_ERROR_METADATAENTRY._options = None
# @@protoc_insertion_point(module_scope)
